# Python Timeit

yet another random library for measuring python performance

## Usage in production

if you do not need to measure performance of your code in a production environment, simply set the environment
variable `TIME_IT` to`false`
